#
# spec file for package cpio (Version 2.6)
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           cpio
Url:            http://www.gnu.org/software/cpio/cpio.html
BuildRequires:  rsh
License:        GPL v2 or later
Group:          Productivity/Archiving/Compression
AutoReqProv:    on
Version:        2.6
Release:        19.28.21
Summary:        A Backup and Archiving Utility
Source:         cpio-2.6.tar.bz2
Patch:          cpio-2.6-mt.patch
Patch1:         cpio-use_new_ascii_format.patch
Patch2:         cpio-use_sbin_rmt.patch
Patch3:         cpio-fix_umask.patch
Patch4:         cpio-sparse.patch
Patch5:         cpio-lstat.patch
Patch6:         cpio-open_nonblock.patch
Patch7:         cpio-2.6-dirTraversal.patch
Patch8:         cpio-2.6-chmodRaceC.patch
Patch9:         cpio-2.6-lfs.patch
Patch10:        cpio-2.6-checksum.patch
Patch11:        cpio-2.6-writeOutHeaderBufferOverflow.patch
#fix handling eof and eod marks (bnc#371077)
Patch13:        cpio-2.6-eof-handling.patch
#fix possible heap overflow in rtapelib.c bnc#579475 
Patch14:        cpio-2.6-heap_overflow_in_rtapelib.patch
PreReq:         %install_info_prereq
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This is GNU cpio, a program to manage archives of files. This package
also includes 'mt', a tape drive control program. Cpio copies files
into or out of a cpio or tar archive. An archive is a file that
contains other files plus information about them, such as their
pathname, owner, time stamps, and access permissions. The archive can
be another file on the disk, a magnetic tape, or a pipe.

This package normally includes the program 'rmt', which provides remote
tape drive control. Because there is a compatible 'rmt' in the 'dump'
package, 'rmt' is not included in this package. If you are planning to
use the remote tape features provided by cpio, install the 'dump'
package as well.



Authors:
--------
    David J. MacKenzie <djm@gnu.ai.mit.edu>
    Jim Meyering <meyering@na-net.ornl.gov>

%prep
%setup
%patch
%patch1
%patch2
%patch3
%patch4
%patch5
%patch6
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch13
%patch14 -p1
chmod 755 .
chmod u+w *
chmod a+r *

%build
autoreconf --force --install
CFLAGS="$RPM_OPT_FLAGS -D_FILE_OFFSET_BITS=64 -D_LARGEFILE_SOURCE" \
./configure DEFAULT_RMT_DIR=/sbin \
    --prefix=/usr \
    --mandir=%{_mandir} \
    --infodir=%{_infodir} \
    --libdir=%{_libdir}
make

%install
mkdir -p $RPM_BUILD_ROOT/{usr/bin,bin}
make prefix=$RPM_BUILD_ROOT/usr infodir=$RPM_BUILD_ROOT/%_infodir mandir=$RPM_BUILD_ROOT/%_mandir install
mv $RPM_BUILD_ROOT/usr/bin/cpio $RPM_BUILD_ROOT/bin
ln -sf ../../bin/cpio $RPM_BUILD_ROOT/usr/bin/cpio

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%files
%defattr(-,root,root)
/bin/cpio
/usr/bin/cpio
/usr/bin/mt
%doc %{_infodir}/cpio.info.gz
%doc %{_mandir}/man1/cpio.1.gz
%doc %{_mandir}/man1/mt.1.gz
/usr/share/locale/*/LC_MESSAGES/cpio.mo

%changelog
* Thu Jan  6 2011 puzel@novell.com
- fixed heap_overflow_in_rtapelib.patch to check the size of the
  right structure when handling ioctl MTIOCGET (bnc#658031)
* Wed Mar  3 2010 mseben@novell.com
- added heap_overflow_in_rtapelib.patch fix possible heap overflow in
  rtapelib.c (bnc#579475)
* Thu Jan 21 2010 mseben@novell.com
- added eof-handling.patch (bnc#371077) and reworked lfs.patch (bnc#367575)
- merged DAT160.patch with mt.patch and added other tape density
  definitions from mt_st package
* Fri Jul 17 2009 mseben@suse.cz
- fix identification of the density code for DAT160 (bnc#415166)
* Fri Jan  4 2008 lmichnovic@suse.cz
- fixed typo with temp in hash table and changed type for some
  forgotten variables (lfs.patch) [#347313]
- merged *mt_bit.patch + cpio-2.6.dif -> cpio-2.6-mt.patch
- merged *security_alloca.patch with *dirTraversal.patch
- not deleting $RPMBUILDROOT in install phase
* Thu Aug 23 2007 lmichnovic@suse.cz
- replaced insecure _alloca_ in *dirTraversal.patch with malloc
  CVE-2007-4476 (security_alloca.patch) [#301416]
* Thu Mar  1 2007 lmichnovic@suse.cz
- disabled mask handling which fixes switching datcompresion
  (cpio-2.6-mt_bit.patch) [#223494]
* Thu Dec 14 2006 lmichnovic@suse.cz
- adjusted mask handling in mt compression plus fixed typo
  (cpio-2.6-mt_bit.patch) [#223494]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Dec  6 2005 fehr@suse.de
- add cpio-2.6-chmodRaceC.patch and cpio-2.6-dirTraversal.patch to
  fix bug #80226
- add cpio-2.6-writeOutHeaderBufferOverflow.patch to fix #133454
- add cpio-2.6-checksum.patch fix wrong checksum on 64bit archs
- add cpio-2.6-lfs.patch to support large files on 32bit archs
* Wed Aug 10 2005 fehr@suse.de
- fix call to setlocale to make multibyte characters work (#98902)
* Thu Jun 30 2005 fehr@suse.de
- open with O_NONBLOCK option (#94449)
* Wed May  4 2005 ro@suse.de
- properly detect lstat in configure
* Wed Apr 27 2005 snwint@suse.de
- fix '--sparse' option check
* Mon Apr 25 2005 fehr@suse.de
- update to cpio 2.6
* Mon Jan 24 2005 fehr@suse.de
- fix problem with cpio not respecting umask (#50054)
* Mon Jan 19 2004 ro@suse.de
- fix build as user
* Sun Jan 11 2004 adrian@suse.de
- add %%defattr
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Tue Apr 15 2003 coolo@suse.de
- use BuildRoot
* Fri Feb  7 2003 fehr@suse.de
- Use %%install_info macro
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Tue Aug 13 2002 mfabian@suse.de
- add cpio-2.5-i18n-0.1.patch received from
  "Mitsuru Chinen" <CHINEN@jp.ibm.com>
  The patch just adds a setlocale (LC_ALL, "").
* Sun Jul 28 2002 kukuk@suse.de
- remove unused tetex from neededforbuild
* Fri Jul  5 2002 fehr@suse.de
- update to new version 2.5
* Mon Dec  3 2001 fehr@suse.de
- make the -c switch comatible to SVR4 (and compatible to RedHat)
- fix the man page accordingly
- add rsh to #needfobuild to allow remote file access again (#12543)
* Sun Dec  3 2000 schwab@suse.de
- Fix a few bugs and typos.
* Tue Nov 28 2000 fehr@suse.de
- add compile options for LFS
* Mon Apr 17 2000 fehr@suse.de
- move cpio binary to /bin for compatibility with RedHat
* Fri Feb 25 2000 kukuk@suse.de
- remove Makefile.Linux
- use _infodir/_mandir
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Sep  2 1999 fehr@suse.de
- Fix patch for broken header (cast to short instead of int)
* Wed Aug  4 1999 kukuk@suse.de
- Add patch for broken header in oldascii format
* Tue Sep 22 1998 ro@suse.de
- define _GNU_SOURCE for glibc where including getopt
* Tue Sep  1 1998 ro@suse.de
- fixed strdup-macro problem
* Thu Jun  5 1997 florian@suse.de
- go through the list of regex in a more suitable way (from ma@suse.de)
* Sun Apr 13 1997 florian@suse.de
- update to new version 2.4.2
- add Linux patches from RedHat
- add patches from gnu.utils.bugs
